@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-26 17:51:04
-:LastEditTime: 2021-04-15 14:43:36
+:LastEditTime: 2021-04-27 11:17:28
 :LastEditors: HuangJingCan
 :Description: 抽奖
 """
@@ -74,7 +74,7 @@ class LotteryHandler(SevenBaseHandler):
         prize_order_model = PrizeOrderModel(db_transaction=db_transaction, context=self)
         machine_value_model = MachineValueModel(db_transaction=db_transaction, context=self)
         #请求太频繁限制
-        if self.check_post(f"Lottery_Post_{act_id}_{str(open_id)}_{str(prize_id)}") == False:
+        if self.check_post(f"Lottery_Post_{act_id}_{open_id}_{prize_id}") == False:
             return self.reponse_json_error("HintMessage", "对不起，请求太频繁")
         user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
         if not user_info:
@@ -110,7 +110,7 @@ class LotteryHandler(SevenBaseHandler):
 
         if machine_info.sale_type == 2:
             sale_date_str = str(machine_info.sale_date)
-            sale_date = TimeHelper.format_time_to_datetime(sale_date_str if sale_date_str != "0000-00-00 00:00:00" else now_date)
+            sale_date = TimeHelper.format_time_to_datetime(sale_date_str if sale_date_str != "1900-01-01 00:00:00" else now_date)
             if TimeHelper.format_time_to_datetime(now_date) < sale_date:
                 china_sale_date = sale_date.month + "月" + sale_date.day + "日" + sale_date.hour + "点"
                 return self.reponse_json_error("NoStart", "该商品" + china_sale_date + "开售,敬请期待~")
@@ -364,7 +364,7 @@ class LotteryAllHandler(SevenBaseHandler):
             return self.reponse_json_error("NoOpen", "对不起，未开启购买端盒")
         if machine_info.sale_type == 2:
             sale_date_str = str(machine_info.sale_date)
-            sale_date = TimeHelper.format_time_to_datetime(sale_date_str if sale_date_str != "0000-00-00 00:00:00" else now_date)
+            sale_date = TimeHelper.format_time_to_datetime(sale_date_str if sale_date_str != "1900-01-01 00:00:00" else now_date)
             if TimeHelper.format_time_to_datetime(now_date) < sale_date:
                 china_sale_date = sale_date.month + "月" + sale_date.day + "日" + sale_date.hour + "点"
                 return self.reponse_json_error("NoStart", "该商品" + china_sale_date + "开售,敬请期待~")
