@@ -2,8 +2,8 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-@LastEditTime: 2021-06-21 15:41:48
-@LastEditors: WangQiang
+@LastEditTime: 2021-07-26 19:52:38
+@LastEditors: HuangJianYi
 :description: 用户处理
 """
 from seven_cloudapp.handlers.top_base import *
@@ -59,6 +59,10 @@ class SyncPayOrderHandler(TopBaseHandler):
         if not act_info:
             return self.reponse_json_error('NoAct', '对不起，活动不存在')
 
+        #请求太频繁限制
+        if self.check_post(f"SyncPayOrderHandler_Post_{str(act_id)}_{str(open_id)}", expire=10) == False:
+            return self.reponse_json_error("NoUser", "对不起，请稍后再试")
+
         # 获取订单
         order_data = self.get_taobao_order(open_id, access_token)
         # self.logging_link_info(str(order_data) + "【订单列表】")
@@ -122,7 +126,7 @@ class SyncPayOrderHandler(TopBaseHandler):
                     pay_order.order_no = order['oid']
                     pay_order.goods_code = order['num_iid']
                     pay_order.goods_name = order['title']
-                    pay_order.sku_id = order['sku_id']
+                    pay_order.sku_id = order['sku_id'] if "sku_id" in order.keys() else ""
                     pay_order.buy_num = order['num']
                     pay_order.pay_price = order['payment']
                     pay_order.order_status = order['status']
